#
# spec file for package geeqie
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           geeqie
Version:        1.6
Release:        bp155.2.14
Summary:        Lightweight Gtk+ based image viewer
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            http://www.geeqie.org
Source0:        %{url}/%{name}-%{version}.tar.xz
Source1:        %{url}/%{name}-%{version}.tar.xz.asc
Source2:        geeqie.keyring
# PATCH-FIX-UPSTREAM 0001-Fix-829-segfault-with-clutter-gtk.patch
Patch0:         0001-Fix-829-segfault-with-clutter-gtk.patch

BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
# Needed to bootstrap the tarball
BuildRequires:  libtool
BuildRequires:  lirc-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(champlain-0.12) >= 0.12
BuildRequires:  pkgconfig(champlain-gtk-0.12) >= 0.12
BuildRequires:  pkgconfig(clutter-1.0) >= 1.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.0
BuildRequires:  pkgconfig(exiv2) >= 0.11
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lua5.1)
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
Geeqie is a lightweight image viewer for Linux, BSDs and compatibles.

%lang_package

%prep
%autosetup -p1

%build
# Needed to bootstrap
intltoolize --copy --force --automake
autoreconf -fvi
%configure \
        --enable-lirc \
        --with-readmedir=%{_defaultdocdir}/%{name} \
        --enable-map \
        %{nil}
%make_build CFLAGS="-Wno-deprecated-declarations"

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}
%fdupes %{buildroot}/%{_prefix}

# Already in the license directory
rm %{buildroot}%{_docdir}/%{name}/COPYING

%files
%license COPYING
%doc AUTHORS ChangeLog ChangeLog.html NEWS TODO README.md README.lirc
%{_bindir}/geeqie
%{_datadir}/applications/geeqie.desktop
%{_datadir}/geeqie/
%{_datadir}/pixmaps/geeqie.png
%{_datadir}/metainfo/org.geeqie.Geeqie.appdata.xml
%{_prefix}/lib/geeqie/
%{_mandir}/man1/geeqie.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Jan  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add upstream patch to fix crash with clutter-gtk (boo#1180228)
  + 0001-Fix-829-segfault-with-clutter-gtk.patch
* Thu Dec  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.6:
  + Support (excluding exif) for heic, webp, psd, cr3, jp2, djvu,
    svg
  + Load remote URLs
  + Save named window layouts
  + Save workspace layout
  + Export duplicates data to file
  + Search and Run command ("/" keystroke)
  + Tiff/pdf multi-page viewing
  + Show over/underexposed
  + Search for broken images
  + Show lens ID
  + File pane - filter by name or class
  + User definable status toolbar
  + Search by path
  + Search on collection
  + Find duplicates with same name but different content
  + User definable mouse buttons 8 and 9 (back/forward)
  + Folder pane list view - sort by name or date
  + Many small improvements
  + Many bug fixes
  + Updated translations.
- Removed geeqie-gcc10-buildfix.patch: Fixed upstream.
* Mon Sep 28 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add geeqie-gcc10-buildfix.patch: Fix build with gcc 10.
- Drop no longer needed desktop_database_post(un) calls from
  post(un), and various other spec modernizations.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Aug 23 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.5.1
  - #626 - High CPU load with animated GIFs
  - #683 - Build failuer on macOS
  - #686 - Zoom lable adjustment
  - #703 - non-glibc fix
  - Lua compatibility
* Wed Jul 31 2019 gutaper@gmail.com
- Update to version 1.5
- Drop exiv-2.0.27-buildfix.patch (fixed in upstream)
- Set CFLAGS="-Wno-deprecated-declarations" (Fix compilation fail)
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add exiv-2.0.27-buildfix.patch.
* Wed Nov  8 2017 gutaper@gmail.com
- Fix SLE_12 rpmlint warning "files-attr-not-set".
* Fri Sep  1 2017 zaitor@opensuse.org
- Enable pkgconfig(champlain-0.12), add
  pkgconfig(champlain-gtk-0.12), pkgconfig(clutter-1.0) and
  pkgconfig(clutter-gtk-1.0) BuildRequires and pass --enable-maps
  to configure: Build map support (boo#1054718).
- Enable conditional pkgconfig(lua5.1) BuildRequires and stop
  passing --disable-lua to configure: New lua is now in place in
  Tumbleweed, build lua support.
* Thu Jul 27 2017 tchvatal@suse.com
- Run just autoreconf and intltoolize, to avoid double configure run
- Add deps for post/postun scriptlets
- Remove dep on lcms and depend on lcms2
* Tue Mar  7 2017 zaitor@opensuse.org
- Add README.lirc explicitly to doc packages, now needed due to
  rpm 4.13 no longer implicitly packages those files.
* Thu Jun 16 2016 dimstar@opensuse.org
- Update to version 1.3 (boo#985090):
  + Sort by creation date.
  + Enhancements in mouse less operation.
  + Rotation invariant duplication search.
  + Better zoom steps.
  + Easy access to working directory when copying ('.').
  + Updated documentation.
  + Speed improvements.
  + Stability improvements.
  + Many bugfixes.
- Enable source signature verification (geeqie.keyring plus
  corresponding .asc file).
* Mon Apr 18 2016 zaitor@opensuse.org
- Update to version 1.2.3:
  + Support for GTK+ 3.
  + Support for lcms2.
  + Basic support for lua scripting.
  + Several bugfixes.
- Replace pkgconfig(gtk+-2.0) for pkgconfig(gtk+-3.0) BuildReqiures
  following upstreams port to gtk3.
- Add disabled pkgconfig(lua-5.1) BuildRequires, configure does not
  find our lua.
- Replace libchamplain-devel for pkgconfig(champlain-0.12)
  BuildRequires, align with what configure looks for, but keep it
  disabled, since upstream deams libchamplain support experimental,
  and it's not the champlain we have in Tumbleweed.
- Add libtool BuildRequires and pass autogen.sh as the tarball is
  not bootstrapped.
- Update package descriptions.
- Update source and Url to new home.
- Drop geeqie-bigendian.patch and geeqie-1.1-fix-bashisms.patch:
  Fixed upstream.
- Remove conditionals for obsolete versions of openSUSE.
* Wed Dec 17 2014 zaitor@opensuse.org
- Rebase patch to match what upstream actually have commited.
* Tue Dec 16 2014 Led <ledest@gmail.com>
- Add geeqie-1.1-fix-bashisms.patch: Fix bashisms in geeqie-rotate
  script.
* Fri Dec 28 2012 dvaleev@suse.com
- Add geeqie-bigendian.patch: fix bigendian build.
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 1.1:
  + Support for stereoscopic images.
  + input: side-by-side (JPS) and MPO format.
  + output: single image, anaglyph, SBS, mirror, SBS half size
    (3DTV).
  + Custom tiff loader - better handling of large tiff files.
  + Rewritten file grouping.
- Add libjpeg-devel and libtiff-devel BuildReqiuires, support jpg,
  and tiff loader.
- Add FIXME entry for champlain support.
- Pass enable-gps to configure, even if this is not taken into
  accout at the moment, libchamplain is not an active
  BuildRequires.
- Change configure switch --with-helpdir to --with-html dir,
  upstream does not support --with-helpdir anymore.
* Tue Sep 27 2011 vuntz@opensuse.org
- Initial package of this gqview fork (version 1.0).
